%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% The regular article class commands still exist and may be used.%%
%% 10pt, 11pt and twocolumn options are disabled.                 %%
%%                                                                %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{medyna2013}

\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{dvips}{%
  \PassOptionsToPackage{dvips}{hyperref}}
\DeclareOption{pdftex}{%
  \PassOptionsToPackage{pdftex}{hyperref}}
\DeclareOption{dvipdfm}{%
  \PassOptionsToPackage{dvipdfm}{hyperref}}
\DeclareOption{dvips}{%
  \PassOptionsToPackage{dvips}{graphicx}}
\DeclareOption{pdftex}{%
  \PassOptionsToPackage{pdftex}{graphicx}}
\DeclareOption{dvipdfm}{%
  \PassOptionsToPackage{dvipdfm}{graphicx}}

\ProcessOptions\relax

\LoadClass[a4paper,12pt]{article}
\RequirePackage[paper=a4paper,lmargin=25mm, rmargin=25mm, bmargin=25mm, tmargin=25mm]{geometry}
\RequirePackage{hyperref}
\RequirePackage{calc}
%\RequirePackage{indentfirst}
\RequirePackage{url}
\RequirePackage{graphicx}
\RequirePackage{times}
\usepackage{here}
\usepackage[numbers,sort&compress]{natbib}
\hyphenation{bran-ches pa-ra-me-ters ar-rhyth-mi-a }

\hypersetup{
colorlinks=true, %colorise les liens
breaklinks=true, %permet le retour  la ligne dans les liens trop longs
urlcolor= black, %couleur des hyperliens
linkcolor= black, %couleur des liens internes
citecolor= black, %couleur des citations
bookmarksopen=true, %si les signets Acrobat sont crs, les afficher compltement.
}

%% Title
\renewcommand{\maketitle}{%
 \newpage

 \begin{centering}
\vspace{0mm}
\includegraphics[width=5cm]{logo_medyna_2013}  \\
\vspace{15pt}
\end{centering}
 \begin{center}%
  {%3
   \fontsize{16}{18}\selectfont
   \bfseries
   \MakeUppercase{\@title}
   \par
  }%3
  \vspace{16pt}%
  {%4
\fontsize{12}{12}\selectfont
   \@author
   \par
  }%4
  \vspace{12pt}%
  {%5
\fontsize{12}{12}\selectfont
   \def\and{\\{\vspace{12pt}}}
   \normalfont\@address
   \par
  }%5
 \end{center}
 \vspace{18pt}%
 \fontsize{12}{14}\selectfont
 \noindent\textbf{\MakeUppercase{Abstract}}\vspace{12pt}\\{\textit{\@abstract}}
\pagestyle{fancy}
% xyz is your paper reference number
\lhead{MEDYNA 2013: 1st Euro-Mediterranean Conference \\on Structural Dynamics and Vibroacoustics}
\rhead{23-25 Apr 2013\\ Marrakech (Morocco)}
\fancyfoot[C]{}  
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.4pt}
\newpage
%% Do not use headers, footers and page number
%\pagestyle{empty}
 }% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\address}[1]{\gdef\@address{#1}}

\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\newcommand{\heading}[1]{\gdef\@heading{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%
%%%  The syntax for the definition of section is (see LaTeX Companion p.24)
%%%
%%%   \renewcommand\section{\@startsection {section}{1}{\z@}%
%%%        {-3.5ex \@plus -1ex \@minus -.2ex}%
%%%        {2.3ex \@plus.2ex}%
%%%        {\reset@font\Large\bfseries}}
%%%
%%%  Explication :
%%%  + {section} name of the sectioning command.
%%%  + {1} Number denoting the depth level of the sectioning command.
%%%  + {\z@} Indentation of the heading (zero).
%%%  + {-3.5ex \@plus -1ex \@minus -.2ex} defined the space to be left
%%%             in front of the heading.
%%%  + {2.3ex \@plus.2ex} defined the space to be left following
%%%             a heading.  If this number is under zero, the
%%%             space is horizontal, in order to have horizontal title
%%%             like :
%%%             Section title.   Here is the text of my section ...
%%%  + \@plus and \@minus allow to stretch and shrink component.
%%%  + {\reset@font\Large\bfseries} Style of the heading text.
%%%
%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\thesection}      {\arabic{section}}

\renewcommand{\section}{\@startsection {section}{1}{0mm}%
                                   {-\baselineskip}%
                                   {1.0\baselineskip}%
                                   {\bfseries\normalsize\MakeUppercase}}

\renewcommand{\thesubsection}   {\thesection.\arabic{subsection}}

\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\bfseries\normalsize}}

%\renewcommand\thesubsubsection{\thesubsection\@arabic\c@subsubsection}

\renewcommand{\thesubsubsection}{\thesubsection.\arabic{subsubsection}}

\renewcommand\subsubsection{\@startsection{subsubsection}{3}{-12.5mm}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalsize\textit}}



%% No headings have number
\setcounter{secnumdepth}{3}



\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize\fontsize{12}{12}\selectfont #1. #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize\fontsize{12}{12}\selectfont #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\renewenvironment{thebibliography}[1]
  {\bigskip
  \section*{\MakeUppercase\refname\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}}%
  \list{\@biblabel{\@arabic\c@enumiv}}%
        {\settowidth\labelwidth{\@biblabel{#1}}%
         \leftmargin\labelwidth
         \advance\leftmargin\labelsep
         \@openbib@code
         \usecounter{enumiv}%
         \let\p@enumiv\@empty
         \renewcommand\theenumiv{\@arabic\c@enumiv}}%
   \sloppy
   \clubpenalty4000
   \@clubpenalty \clubpenalty
   \widowpenalty4000%
   \sfcode`\.\@m}
  {\def\@noitemerr
   {\@latex@warning{Empty `thebibliography' environment}}%
   \endlist}

\setlength{\parindent}{12.5mm}

\AtBeginDocument{%
  \pagestyle{empty}
  \maketitle
  \let\maketitle\relax
}
\def\refname{REFERENCES}
\RequirePackage{natbib}
\setlength{\bibsep}{0.5pt} % Get rid of the spacing between references
\bibliographystyle{unsrt}
%\bibliographystyle{h-physrev3}
%\bibliographystyle{ieeetr}

%% Do not use headers, footers and page number
\pagestyle{empty}


\endinput
